@@ -1,13 +1,12 @@
 """Serverless process manager."""
 
-import json
 import locale
 import logging
 import os
 import signal
 import sys
 import time
-from typing import Generator, List, Optional, Tuple, Union
+from typing import Dict, Generator, List, Optional, Tuple, Union
 
 from celery import Signature, signature  # pylint: disable=no-name-in-module
 from funcy.flow import reraise
@@ -49,16 +48,14 @@ class ProcessManager:
     def __getitem__(self, key: str) -> "ProcessInfo":
         info_path = self._get_info_path(key)
         try:
-            with open(info_path, encoding="utf-8") as fobj:
-                return ProcessInfo.from_dict(json.load(fobj))
+            return ProcessInfo.load(info_path)
         except FileNotFoundError as exc:
             raise KeyError from exc
 
     @reraise(FileNotFoundError, KeyError)
     def __setitem__(self, key: str, value: "ProcessInfo"):
         info_path = self._get_info_path(key)
-        with open(info_path, "w", encoding="utf-8") as fobj:
-            return json.dump(value.asdict(), fobj)
+        value.dump(info_path)
 
     def __delitem__(self, key: str) -> None:
         path = os.path.join(self.wdir, key)
@@ -83,26 +80,38 @@ class ProcessManager:
             except KeyError:
                 continue
 
-    def run(
+    def run_signature(
         self,
         args: Union[str, List[str]],
         name: Optional[str] = None,
         task: Optional[str] = None,
+        env: Optional[Dict[str, str]] = None,
+        immutable: bool = False,
     ) -> Signature:
-        """Return a task which would run the given command in the background.
+        """Return signature for a task which runs a command in the background.
 
         Arguments:
             args: Command to run.
             name: Optional name to use for the spawned process.
             task: Optional name of Celery task to use for spawning the process.
                 Defaults to 'dvc_task.proc.tasks.run'.
+            env: Optional environment to be passed into the process.
+            immutable: True if the returned Signature should be immutable.
+
+        Returns:
+            Celery signature for the run task.
         """
         name = name or uuid()
         task = task or "dvc_task.proc.tasks.run"
         return signature(
             task,
             args=(args,),
-            kwargs={"name": name, "wdir": os.path.join(self.wdir, name)},
+            kwargs={
+                "name": name,
+                "wdir": os.path.join(self.wdir, name),
+                "env": env,
+            },
+            immutable=immutable,
         )
 
     def send_signal(self, name: str, sig: int):
